/*
ThunderBayes is licensed under the terms of the MIT License.

Copyright (C) 2006 Daniel Miller <millerdev@gmail.com>

The Initial Developer of this code is Patrick Brunschwig.
Portions created by Patrick Brunschwig <patrick.brunschwig@gmx.net> are
Copyright (C) 2003 Patrick Brunschwig. All Rights Reserved.

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

// components defined in this file
const THUNDERBAYES_PREFS_EXTENSION_SERVICE_CONTRACTID =
		"@mozilla.org/accountmanager/extension;1?name=thunderbayes";
const THUNDERBAYES_PREFS_EXTENSION_SERVICE_CID =
		Components.ID("{83d1f945-8280-11db-96a7-00e08161165f}");

// interafces used in this file
const nsIMsgAccountManagerExtension	= Components.interfaces.nsIMsgAccountManagerExtension;
const nsICategoryManager = Components.interfaces.nsICategoryManager;
const nsISupports = Components.interfaces.nsISupports;

function ThunderBayesPrefService() {}

ThunderBayesPrefService.prototype.name = "thunderbayes";
ThunderBayesPrefService.prototype.chromePackageName = "thunderbayes";
ThunderBayesPrefService.prototype.showPanel = function (server) {
	// show ThunderBayes panel for POP3 accounts only...more to come?
	return (server && server.type == "pop3");
}

// factory for command line handler service (ThunderBayesPrefService)
var ThunderBayesPrefFactory = new Object();

ThunderBayesPrefFactory.createInstance = function (outer, iid) {
	if (outer != null)
		throw Components.results.NS_ERROR_NO_AGGREGATION;
	if (!iid.equals(nsIMsgAccountManagerExtension) && !iid.equals(nsISupports))
		throw Components.results.NS_ERROR_INVALID_ARG;
	return new ThunderBayesPrefService();
}


var ThunderBayesPrefsModule = new Object();

ThunderBayesPrefsModule.registerSelf =
function (compMgr, fileSpec, location, type) {
	dump("Registering ThunderBayes account manager extension.\n");

	compMgr = compMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
	compMgr.registerFactoryLocation(THUNDERBAYES_PREFS_EXTENSION_SERVICE_CID,
		"ThunderBayes Account Manager Extension Service",
		THUNDERBAYES_PREFS_EXTENSION_SERVICE_CONTRACTID,
		fileSpec,
		location,
		type
	);
	catman = Components.classes["@mozilla.org/categorymanager;1"].getService(nsICategoryManager);
	catman.addCategoryEntry("mailnews-accountmanager-extensions",
		"ThunderBayes account manager extension",
		THUNDERBAYES_PREFS_EXTENSION_SERVICE_CONTRACTID, true, true
	);
	dump("ThunderBayes account manager extension registered.\n");
}

ThunderBayesPrefsModule.unregisterSelf = function(compMgr, fileSpec, location) {
	compMgr = compMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
	compMgr.unregisterFactoryLocation(THUNDERBAYES_PREFS_EXTENSION_SERVICE_CID, fileSpec);
	catman = Components.classes["@mozilla.org/categorymanager;1"].getService(nsICategoryManager);
	catman.deleteCategoryEntry("mailnews-accountmanager-extensions",
		THUNDERBAYES_PREFS_EXTENSION_SERVICE_CONTRACTID, true
	);
}

ThunderBayesPrefsModule.getClassObject = function (compMgr, cid, iid) {
	if (cid.equals(THUNDERBAYES_PREFS_EXTENSION_SERVICE_CID))
		return ThunderBayesPrefFactory;
	if (!iid.equals(Components.interfaces.nsIFactory))
		throw Components.results.NS_ERROR_NOT_IMPLEMENTED;
	throw Components.results.NS_ERROR_NO_INTERFACE;		
}

ThunderBayesPrefsModule.canUnload = function(compMgr) {
	return true;
}

// entrypoint
function NSGetModule(compMgr, fileSpec) {
	return ThunderBayesPrefsModule;
}
